@@ -1,5 +1,4 @@
-# $Id: Paged.pm,v 1.3 2000/07/30 21:03:50 gbarr Exp $
-# Copyright (c) 2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2000-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -9,7 +8,7 @@ use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
 @ISA = qw(Net::LDAP::Control);
-$VERSION = "0.01";
+$VERSION = "0.02";
 
 use Net::LDAP::ASN qw(realSearchControlValue);
 use strict;
@@ -107,20 +106,20 @@ Net::LDAP::Control::Paged - LDAPv3 Paged results control object
 
 =head1 DESCRIPTION
 
-C<Net::LDAP::Control::Paged> provides an interface for the creation and manipulatrion
+C<Net::LDAP::Control::Paged> provides an interface for the creation and manipulation
 of objects that represent the C<pagedResultsControl> as described by RFC-2696.
 
 =head1 CONSTRUCTOR ARGUMENTS
 
 In addition to the constructor arguments described in
-L<Net::LDAP::Control|Net::LDAP::Control> the following are provided.
+L<Net::LDAP::Control> the following are provided.
 
 =over 4
 
 =item cookie
 
 The value to use as the cookie. This is not normally set when an object is
-created, but is set from the cookie value returned bu the server. This associates
+created, but is set from the cookie value returned by the server. This associates
 a search with a previous search, so the server knows to return the page
 of entries following the entries it returned the previous time.
 
@@ -133,33 +132,29 @@ server will return to the search request.
 
 =head1 METHODS
 
-As with L<Net::LDAP::Control|Net::LDAP::Control> each constructor argument
+As with L<Net::LDAP::Control> each constructor argument
 described above is also avaliable as a method on the object which will
 return the current value for the attribute if called without an argument,
 and set a new value for the attribute if called with an argument.
 
 =head1 SEE ALSO
 
-L<Net::LDAP|Net::LDAP>,
-L<Net::LDAP::Control|Net::LDAP::Control>,
-http://info.internet.isi.edu/in-notes/rfc/files/rfc2696.txt
+L<Net::LDAP>,
+L<Net::LDAP::Control>,
+http://www.ietf.org/rfc/rfc2696.txt
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr E<lt>gbarr@pobox.comE<gt>
 
 Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap-dev@lists.sourceforge.net>
+E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000 Graham Barr. All rights reserved. This program is
+Copyright (c) 2000-2004 Graham Barr. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
-=for html <hr>
-
-I<$Id: Paged.pm,v 1.3 2000/07/30 21:03:50 gbarr Exp $>
-
 =cut
 
