@@ -4,10 +4,11 @@
 
 package Net::LDAP::Control::PostRead;
 
+use vars qw(@ISA $VERSION);
 use Net::LDAP::Control::PreRead;
 
-our @ISA = qw(Net::LDAP::Control::PreRead);
-our $VERSION = "0.02";
+@ISA = qw(Net::LDAP::Control::PreRead);
+$VERSION = "0.01";
 
 1;
 
@@ -26,7 +27,7 @@ Net::LDAP::Control::PostRead - LDAPv3 Post-Read control object
 
  $ldap = Net::LDAP->new( "ldap.mydomain.eg" );
 
- $postread = Net::LDAP::Control::PostRead->new( attrs => [ qw/givenName/ ] );
+ $postread = Net::LDAP::Control::Paged->new( attrs => [ qw/givenName/ ] );
 
  my $mesg = $ldap->modify( "cn=Barbara Jensen, o=University of Michigan, c=US",
                            replace => { givenName => "Babs" },
@@ -41,25 +42,15 @@ Net::LDAP::Control::PostRead - LDAPv3 Post-Read control object
            join("', '", $entry->get_value(givenName") .
            "' to 'Babs'\n");
    }
- }
-
+ }  
+   
 
 =head1 DESCRIPTION
 
 C<Net::LDAP::Control::PostRead> provides an interface for the creation and
-manipulation of objects that represent the C<Post-Read Controls> as described
+manipulation of objects that represent the C<Post-Read Control> as described
 by RFC 4527.
 
-In modification operations, the C<Post-Read request control> indicates to the
-server that a copy of the modified entry after the update is to be returned.
-After the successful completion of the operation, the accompanying C<Post-Read
-response control> allows one to retrieve the updated value from the servers's response.
-
-One use case of this control may be to obtain values of operational attributes,
-such as the C<entryUUID> and C<modifyTimestamp> attributes, updated by the server
-as part of the update operation.
-
-
 =head1 CONSTRUCTOR ARGUMENTS
 
 In addition to the constructor arguments described in
@@ -73,16 +64,15 @@ A list of attributes to be returned in the entry returned in the response contro
 
 If absent, all attributes are returned.
 
-Operational attributes may be included in the list by explicitly asking for them
+Operational attributes may be included in the list by explicitely asking for them
 or by using special C<"+"> feature (provided the server supports this feature).
 
 =back
 
-
 =head1 METHODS
 
 As with L<Net::LDAP::Control> each constructor argument
-described above is also available as a method on the object which will
+described above is also avaliable as a method on the object which will
 return the current value for the attribute if called without an argument,
 and set a new value for the attribute if called with an argument.
 
@@ -115,7 +105,7 @@ E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2011 Peter Marschall. All rights reserved. This program is
+Copyright (c) 2008 Peter Marschall. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
