@@ -1,5 +1,4 @@
-# $Id: VLV.pm,v 1.6 2003/05/07 11:57:57 chrisridd Exp $
-# Copyright (c) 2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2000-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -229,7 +228,7 @@ Net::LDAP::Control::VLV - LDAPv3 Virtual List View control object
 	   content => 0,	# List size unknown
 	   offset  => 1,	# Target entry is the first
 	 );
- $sort = Net::LDAP::Control::Sort->new( sort => 'cn' );
+ $sort = Net::LDAP::Control::Sort->new( order => 'cn' );
 
  @args = ( base     => "o=Ace Industry, c=us",
 	   scope    => "subtree",
@@ -266,7 +265,7 @@ Net::LDAP::Control::VLV - LDAPv3 Virtual List View control object
  $vlv->before(9);	# Change page to show 9 before
  $vlv->after(10);	# Change page to show 10 after
  $vlv->assert("B");	# assert "B"
- 
+
  $mesg = $ldap->search( @args );
 
 =head1 DESCRIPTION
@@ -393,11 +392,8 @@ E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000 Graham Barr. All rights reserved. This program is
+Copyright (c) 2000-2004 Graham Barr. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
-=for html <hr>
-
-I<$Id: VLV.pm,v 1.6 2003/05/07 11:57:57 chrisridd Exp $>
-
+=cut
