@@ -1,4 +1,4 @@
-# Copyright (c) 1997-2003 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -6,10 +6,18 @@ package Net::LDAP::Entry;
 
 use strict;
 use Net::LDAP::ASN qw(LDAPEntry);
-use Net::LDAP::Constant qw(LDAP_LOCAL_ERROR);
+use Net::LDAP::Constant qw(LDAP_LOCAL_ERROR LDAP_OTHER);
 use vars qw($VERSION);
 
-$VERSION = "0.21";
+use constant CHECK_UTF8 => $] > 5.007;
+
+BEGIN {
+  require Encode
+    if (CHECK_UTF8);
+}
+
+
+$VERSION = "0.24";
 
 sub new {
   my $self = shift;
@@ -17,7 +25,10 @@ sub new {
 
   my $entry = bless { 'changetype' => 'add', changes => [] }, $type;
 
-  $entry;
+  @_ and $entry->dn( shift );
+  @_ and $entry->add( @_ );
+
+  return $entry;
 }
 
 sub clone {
@@ -55,9 +66,20 @@ sub decode {
   my $self = shift;
   my $result = ref($_[0]) ? shift : $LDAPEntry->decode(shift)
     or return;
+  my %arg = @_;
 
   %{$self} = ( asn => $result, changetype => 'modify', changes => []);
 
+  if (CHECK_UTF8 && $arg{raw}) {
+    $result->{objectName} = Encode::decode_utf8($result->{objectName})
+      if ('dn' !~ /$arg{raw}/);
+  
+    foreach my $elem (@{$self->{asn}{attributes}}) {
+      map { $_ = Encode::decode_utf8($_) } @{$elem->{vals}}
+        if ($elem->{type} !~ /$arg{raw}/);
+    }
+  }
+
   $self;
 }
 
@@ -118,10 +140,12 @@ sub get_value {
 
 
 sub changetype {
+
   my $self = shift;
   return $self->{'changetype'} unless @_;
   $self->{'changes'} = [];
   $self->{'changetype'} = shift;
+  return $self;
 }
 
 
@@ -132,12 +156,12 @@ sub add {
   my $attrs = $self->{attrs} ||= _build_attrs($self);
 
   while (my($type,$val) = splice(@_,0,2)) {
-    $type = lc $type;
+    my $lc_type = lc $type;
 
-    push @{$self->{asn}{attributes}}, { type => $type, vals => ($attrs->{$type}=[])}
-      unless exists $attrs->{$type};
+    push @{$self->{asn}{attributes}}, { type => $type, vals => ($attrs->{$lc_type}=[])}
+      unless exists $attrs->{$lc_type};
 
-    push @{$attrs->{$type}}, ref($val) ? @$val : $val;
+    push @{$attrs->{$lc_type}}, ref($val) ? @$val : $val;
 
     push @$cmd, $type, [ ref($val) ? @$val : $val ]
       if $cmd;
@@ -145,6 +169,8 @@ sub add {
   }
 
   push(@{$self->{'changes'}}, 'add', $cmd) if $cmd;
+
+  return $self;
 }
 
 
@@ -154,24 +180,24 @@ sub replace {
   my $attrs = $self->{attrs} ||= _build_attrs($self);
 
   while(my($type, $val) = splice(@_,0,2)) {
-    $type = lc $type;
+    my $lc_type = lc $type;
 
     if (defined($val) and (!ref($val) or @$val)) {
 
-      push @{$self->{asn}{attributes}}, { type => $type, vals => ($attrs->{$type}=[])}
-	unless exists $attrs->{$type};
+      push @{$self->{asn}{attributes}}, { type => $type, vals => ($attrs->{$lc_type}=[])}
+	unless exists $attrs->{$lc_type};
 
-      @{$attrs->{$type}} = ref($val) ? @$val : ($val);
+      @{$attrs->{$lc_type}} = ref($val) ? @$val : ($val);
 
       push @$cmd, $type, [ ref($val) ? @$val : $val ]
 	if $cmd;
 
     }
     else {
-      delete $attrs->{$type};
+      delete $attrs->{$lc_type};
 
       @{$self->{asn}{attributes}}
-	= grep { $type ne lc($_->{type}) } @{$self->{asn}{attributes}};
+	= grep { $lc_type ne lc($_->{type}) } @{$self->{asn}{attributes}};
 
       push @$cmd, $type, []
 	if $cmd;
@@ -180,6 +206,8 @@ sub replace {
   }
 
   push(@{$self->{'changes'}}, 'replace', $cmd) if $cmd;
+
+  return $self;
 }
 
 
@@ -195,77 +223,103 @@ sub delete {
   my $attrs = $self->{attrs} ||= _build_attrs($self);
 
   while(my($type,$val) = splice(@_,0,2)) {
-    $type = lc $type;
+    my $lc_type = lc $type;
 
     if (defined($val) and (!ref($val) or @$val)) {
       my %values;
-      @values{@$val} = ();
+      @values{(ref($val) ? @$val : $val)} = ();
 
-      unless( @{$attrs->{$type}}
-        = grep { !exists $values{$_} } @{$attrs->{$type}})
+      unless( @{$attrs->{$lc_type}}
+        = grep { !exists $values{$_} } @{$attrs->{$lc_type}})
       {
-	delete $attrs->{$type};
+	delete $attrs->{$lc_type};
 	@{$self->{asn}{attributes}}
-	  = grep { $type ne lc($_->{type}) } @{$self->{asn}{attributes}};
+	  = grep { $lc_type ne lc($_->{type}) } @{$self->{asn}{attributes}};
       }
 
       push @$cmd, $type, [ ref($val) ? @$val : $val ]
 	if $cmd;
     }
     else {
-      delete $attrs->{$type};
+      delete $attrs->{$lc_type};
 
       @{$self->{asn}{attributes}}
-	= grep { $type ne lc($_->{type}) } @{$self->{asn}{attributes}};
+	= grep { $lc_type ne lc($_->{type}) } @{$self->{asn}{attributes}};
 
       push @$cmd, $type, [] if $cmd;
     }
   }
 
   push(@{$self->{'changes'}}, 'delete', $cmd) if $cmd;
+
+  return $self;
 }
 
 
 sub update {
   my $self = shift;
-  my $ldap = shift;
+  my $target = shift;	# a Net::LDAP or a Net::LDAP::LDIF object
+  my %opt = @_;
   my $mesg;
-  my $cb = sub { $self->changetype('modify') unless $_[0]->code };
+  my $user_cb = delete $opt{callback};
+  my $cb = sub { $self->changetype('modify') unless $_[0]->code;
+                 $user_cb->(@_) if $user_cb };
 
-  if ($self->{'changetype'} eq 'add') {
-    $mesg = $ldap->add($self, 'callback' => $cb);
+  if (ref($target) && UNIVERSAL::isa($target, 'Net::LDAP')) {
+    if ($self->{'changetype'} eq 'add') {
+      $mesg = $target->add($self, 'callback' => $cb, %opt);
+    }
+    elsif ($self->{'changetype'} eq 'delete') {
+      $mesg = $target->delete($self, 'callback' => $cb, %opt);
+    }
+    elsif ($self->{'changetype'} =~ /modr?dn/o) {
+      my @args = (newrdn => $self->get_value('newrdn') || undef,
+                  deleteoldrdn => $self->get_value('deleteoldrdn') || undef);
+      my $newsuperior = $self->get_value('newsuperior');
+      push(@args, newsuperior => $newsuperior) if $newsuperior;
+      $mesg = $target->moddn($self, @args, 'callback' => $cb, %opt);
+    }
+    elsif (@{$self->{'changes'}}) {
+      $mesg = $target->modify($self, 'changes' => $self->{'changes'}, 'callback' => $cb, %opt);
+    }
+    else {
+      require Net::LDAP::Message;
+      $mesg = Net::LDAP::Message->new( $target );
+      $mesg->set_error(LDAP_LOCAL_ERROR,"No attributes to update");
+    }
   }
-  elsif ($self->{'changetype'} eq 'delete') {
-    $mesg = $ldap->delete($self, 'callback' => $cb);
-  }
-  elsif ($self->{'changetype'} =~ /modr?dn/) {
-    my @args = (newrdn => $self->get_value('newrdn'),
-                deleteoldrdn => $self->get_value('deleteoldrdn'));
-    my $newsuperior = $self->get_value('newsuperior');
-    push(@args, newsuperior => $newsuperior) if $newsuperior;
-    $mesg = $ldap->moddn($self, @args, 'callback' => $cb);
-  }
-  elsif (@{$self->{'changes'}}) {
-    $mesg = $ldap->modify($self, 'changes' => $self->{'changes'}, 'callback' => $cb);
-  }
-  else {
-    require Net::LDAP::Message;
-    $mesg = Net::LDAP::Message->new( $ldap );
-    $mesg->set_error(LDAP_LOCAL_ERROR,"No attributes to update");
+  elsif (ref($target) && UNIVERSAL::isa($target, 'Net::LDAP::LDIF')) {
+    $target->write_entry($self);
+    $mesg = Net::LDAP::Message::Dummy->new();
+    $mesg->set_error(LDAP_OTHER, $target->error())
+      if ($target->error());
   }
 
   return $mesg;
 }
 
+sub ldif {
+  my $self = shift;
+  my %opt = @_;
+
+  require Net::LDAP::LDIF;
+  open(my $fh, ">", \my $buffer);
+  my $change = exists $opt{change} ? $opt{change} : $self->changes ? 1 : 0;
+  my $ldif = Net::LDAP::LDIF->new($fh, "w", change => $change);
+  $ldif->write_entry($self);
+  return $buffer;
+}
 
 # Just for debugging
 
 sub dump {
   my $self = shift;
+  no strict 'refs'; # select may return a GLOB name
+  my $fh = @_ ? shift : select;
 
   my $asn = $self->{asn};
-  print "-" x 72,"\n";
-  print "dn:",$asn->{objectName},"\n\n" if $asn->{objectName};
+  print $fh "-" x 72,"\n";
+  print $fh "dn:",$asn->{objectName},"\n\n" if $asn->{objectName};
 
   my($attr,$val);
   my $l = 0;
@@ -278,14 +332,14 @@ sub dump {
 
   foreach $attr (@{$asn->{attributes}}) {
     $val = $attr->{vals};
-    printf "%${l}s: ", $attr->{type};
+    printf $fh "%${l}s: ", $attr->{type};
     my($i,$v);
     $i = 0;
     foreach $v (@$val) {
-      print $spc if $i++;
-      print $v;
+      print $fh $spc if $i++;
+      print $fh $v;
     }
-    print "\n";
+    print $fh "\n";
   }
 }
 
