@@ -1,4 +1,4 @@
-# Copyright (c) 1997-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -7,7 +7,7 @@ package Net::LDAP::Filter;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "0.14";
+$VERSION = "0.15";
 
 # filter       = "(" filtercomp ")"
 # filtercomp   = and / or / not / item
@@ -88,7 +88,7 @@ sub _unescape {
   $_[0];
 }
 
-sub _escape { (my $t = $_[0]) =~ s/([\\\(\)\*\0-\37])/sprintf("\\%02x",ord($1))/sge; $t }
+sub _escape { (my $t = $_[0]) =~ s/([\\\(\)\*\0-\37\177-\377])/sprintf("\\%02x",ord($1))/sge; $t }
 
 sub _encode {
   my($attr,$op,$val) = @_;
@@ -159,6 +159,12 @@ sub parse {
 
   undef $ErrStr;
 
+  # a filter is required
+  if (!defined $filter) {
+    $ErrStr = "Undefined filter";
+    return undef;
+  }
+
   # Algorithm depends on /^\(/;
   $filter =~ s/^\s*//;
 
