@@ -1,4 +1,4 @@
-# Copyright (c) 1997-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2008 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -17,7 +17,7 @@ BEGIN {
 }  
 
 
-$VERSION = "0.17";
+$VERSION = "0.18";
 
 my %mode = qw(w > r < a >>);
 
@@ -126,6 +126,7 @@ sub _read_lines {
     }
   }
   $self->eof(1)  if (!defined($ln));
+  $self->{_current_lines} = $entry;
   $entry =~ s/\r?\n //sgo;	# un-wrap wrapped lines
   $entry =~ s/\r?\n\t/ /sgo;	# OpenLDAP extension !!!
   @ldif = split(/^/, $entry);
@@ -186,7 +187,7 @@ sub _read_entry {
       unless @ldif;
   }
 
-  if (@ldif <= 1) {
+  if (@ldif < 1) {
      $self->_error("LDIF entry is not valid", @ldif);
      return;
   }
@@ -211,7 +212,7 @@ sub _read_entry {
     if (CHECK_UTF8 && $self->{raw} && ('dn' !~ /$self->{raw}/));
   $entry->dn($dn);
 
-  if ($ldif[0] =~ /^changetype:\s*/) {
+  if ((scalar @ldif) && ($ldif[0] =~ /^changetype:\s*/)) {
     my $changetype = $ldif[0] =~ s/^changetype:\s*//
         ? shift(@ldif) : $self->{'changetype'};
     $entry->changetype($changetype);
@@ -228,7 +229,7 @@ sub _read_entry {
       my $modattr;
       my $lastattr;
       if($changetype eq "modify") {
-        unless ( (my $tmp = shift @ldif) =~ s/^(add|delete|replace):\s*([-;\w]+)// ) {
+        unless ( (my $tmp = shift @ldif) =~ s/^(add|delete|replace|increment):\s*([-;\w]+)// ) {
           $self->_error("LDAP entry is not valid",@ldif); 
           return;
         }
@@ -384,8 +385,8 @@ sub eof {
 }
 
 sub _wrap {
-  my $len=$_[1];
-  return $_[0] if length($_[0]) <= $len;
+  my $len=$_[1];	# needs to be >= 2 to avoid division by zero
+  return $_[0] if length($_[0]) <= $len or $len <= 40;
   use integer;
   my $l2 = $len-1;
   my $x = (length($_[0]) - $len) / $l2;
@@ -445,6 +446,7 @@ sub _write_dn {
       # Canonicalizer won't fix leading spaces, colons or less-thans, which
       # are special in LDIF, so we fix those up here.
       $dn =~ s/^([ :<])/\\$1/;
+      $dn = "dn: $dn";
     } elsif ($encode =~ /base64/i) {
       require MIME::Base64;
       $dn = "dn:: " . MIME::Base64::encode($dn,"");
