@@ -1,4 +1,4 @@
-# Copyright (c) 1999-2002 Graham Barr <gbarr@pobox.com> and
+# Copyright (c) 1999-2004 Graham Barr <gbarr@pobox.com> and
 # Norbert Klasen <norbert.klasen@daasi.de> All Rights Reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -41,8 +41,21 @@ require Net::LDAP::Constant;
   ldap_error_desc
   canonical_dn
   ldap_explode_dn
+  escape_filter_value
+  unescape_filter_value
+  escape_dn_value
+  unescape_dn_value
 );
-$VERSION = "0.10";
+%EXPORT_TAGS = (
+	error	=> [ qw(ldap_error_name ldap_error_text ldap_error_desc) ],
+	filter	=> [ qw(escape_filter_value unescape_filter_value) ],
+	dn    	=> [ qw(canonical_dn ldap_explode_dn
+	                escape_dn_value unescape_dn_value) ],
+	escape 	=> [ qw(escape_filter_value unescape_filter_value
+	                escape_dn_value unescape_dn_value) ],
+);
+
+$VERSION = "0.11";
 
 =item ldap_error_name ( ERR )
 
@@ -225,7 +238,7 @@ B<OPTIONS> is a list of name/value pairs, valid options are:
 
 Controls case folding of attribute type names. Attribute values are not
 affected by this option. The default is to uppercase. Valid values are:
-	
+
 =over 4
 
 =item lower
@@ -267,7 +280,7 @@ sub canonical_dn($%) {
   # create array of hash representation
   my $rdns = ref($dn) eq 'ARRAY'
 		? $dn
-		: ldap_explode_dn( $dn )
+		: ldap_explode_dn( $dn, casefold => $opt{casefold} || 'upper')
     or return undef; #error condition
   
   # assign specified or default separator value
@@ -296,6 +309,8 @@ sub canonical_dn($%) {
             #escape leading and trailing whitespace
             $val =~ s/(^\s+|\s+$)/
               "\\20" x length $1/xeg; 
+            #compact multiple spaces
+            $val =~ s/\s+/ /g;
           }
           
           # case fold attribute type and create return value
@@ -321,42 +336,42 @@ sub canonical_dn($%) {
 Explodes the given B<DN> into an array of hashes and returns a reference to this 
 array. Returns undef if B<DN> is not a valid Distinguished Name.
 
-A Distinguished Name is a sequence of Relative Distingushed Names (RDNs), which 
+A Distinguished Name is a sequence of Relative Distinguished Names (RDNs), which 
 themselves are sets of Attributes. For each RDN a hash is constructed with the 
 attribute type names as keys and the attribute values as corresponding values. 
-These hashes are then strored in an array in the order in which they appear 
+These hashes are then stored in an array in the order in which they appear 
 in the DN.
 
 For example, the DN 'OU=Sales+CN=J. Smith,DC=example,DC=net' is exploded to:
-[
-  {
-    'OU' =E<gt> 'Sales',
-    'CN' =E<gt> 'J. Smith'
-  },
-  {
-    'DC' =E<gt> 'example'
-  },
-  {
-    'DC' =E<gt> 'net'
-  }
-]
+ [
+   {
+     'OU' =E<gt> 'Sales',
+     'CN' =E<gt> 'J. Smith'
+   },
+   {
+     'DC' =E<gt> 'example'
+   },
+   {
+     'DC' =E<gt> 'net'
+   }
+ ]
 
 (RFC2253 string) DNs might also contain values, which are the bytes of the 
 BER encoding of the X.500 AttributeValue rather than some LDAP string syntax. 
-These values are hex-encoded and prefixed with a #. To distingush such BER 
+These values are hex-encoded and prefixed with a #. To distinguish such BER 
 values, ldap_explode_dn uses references to the actual values, 
 e.g. '1.3.6.1.4.1.1466.0=#04024869,DC=example,DC=com' is exploded to:
-[
-  {
-    '1.3.6.1.4.1.1466.0' =E<gt> \"\004\002Hi"
-  },
-  {
-    'DC' =E<gt> 'example'
-  },
-  {
-    'DC' =E<gt> 'com'
-  }
-];
+ [
+   {
+     '1.3.6.1.4.1.1466.0' =E<gt> "\004\002Hi"
+   },
+   {
+     'DC' =E<gt> 'example'
+   },
+   {
+     'DC' =E<gt> 'com'
+   }
+ ];
 
 It also performs the following operations on the given DN:
 
@@ -369,7 +384,7 @@ Unescape "\" followed by ",", "+", """, "\", "E<lt>", "E<gt>", ";",
 
 =item *
 
-Removes the leading OID. characters if the type is an OID instead
+Removes the leading 'OID.' characters if the type is an OID instead
 of a name.
 
 =back
@@ -382,7 +397,7 @@ B<OPTIONS> is a list of name/value pairs, valid options are:
 
 Controls case folding of attribute types names. Attribute values are not
 affected by this option. The default is to uppercase. Valid values are:
-	
+
 =over 4
 
 =item lower
@@ -397,14 +412,14 @@ Uppercase attribute type names. This is the default.
 
 Do not change attribute type names.
 
+=back
+
 =item reverse
 
 If TRUE, the RDN sequence is reversed.
 
 =back
 
-=back
-
 =cut
 
 sub ldap_explode_dn($%) {
@@ -472,15 +487,126 @@ sub ldap_explode_dn($%) {
 }
 
 
+=item escape_filter_value ( VALUES )
+
+Escapes the given B<VALUES> according to RFC 2254 so that they
+can be safely used in LDAP filters.
+
+Any control characters with an ACII code E<lt> 32 as well as the
+characters with special meaning in LDAP filters "*", "(", ")",
+and "\" the backslash are converted into the representation
+of a backslash followed by two hex digits representing the
+hexadecimal value of the character.
+
+Returns the converted list in list mode and the first element
+in scalar mode.
+
+=cut
+
+## convert a list of values into its LDAP filter encoding ##
+# Synopsis:  @escaped = escape_filter_value(@values)
+sub escape_filter_value(@)
+{
+my @values = @_;
+
+  map { $_ =~ s/([\x00-\x1F\*\(\)\\])/"\\".unpack("H2",$1)/oge; } @values;
+
+  return(wantarray ? @values : $values[0]);
+}
+
+
+=item unescape_filter_value ( VALUES )
+
+Undoes the conversion done by B<escape_filter_value()>.
+
+Converts any sequences of a backslash followed by two hex digits
+into the corresponding character.
+
+Returns the converted list in list mode and the first element
+in scalar mode.
+
+=cut
+
+## convert a list of values from its LDAP filter encoding ##
+# Synopsis:  @values = unescape_filter_value(@escaped)
+sub unescape_filter_value(@)
+{
+my @values = @_;
+
+  map { $_ =~ s/\\([0-9a-fA-F]{2})/pack("H2",$1)/oge; } @values;
+
+  return(wantarray ? @values : $values[0]);
+}
+
+
+=item escape_dn_value ( VALUES )
+
+Escapes the given B<VALUES> according to RFC 2253 so that they
+can be safely used in LDAP DNs.
+
+The characters ",", "+", """, "\", "E<lt>", "E<gt>", ";", "#", "="
+with a special meaning in RFC 2252 are preceeded by ba backslash.
+Control characters with an ASCII code E<lt> 32 are represented
+as \hexpair.
+Finally all leading and trailing spaces are converted to
+sequences of \20.
+
+Returns the converted list in list mode and the first element
+in scalar mode.
+
+=cut
+
+## convert a list of values into its DN encoding ##
+# Synopsis:  @escaped = escape_dn_value(@values)
+sub escape_dn_value(@)
+{
+my @values = @_;
+
+  map { $_ =~ s/([\\",=+<>#;])/\\$1/og;
+        $_ =~ s/([\x00-\x1F])/"\\".unpack("H2",$1)/oge;
+        $_ =~ s/(^\s+|\s+$)/"\\20" x length($1)/oge; } @values;
+
+  return(wantarray ? @values : $values[0]);
+}
+
+
+=item unescape_dn_value ( VALUES )
+
+Undoes the conversion done by B<escape_dn_value()>.
+
+Any escape sequence starting with a baskslash - hexpair or
+special character - will be transformed back to the
+corresponding character.
+
+Returns the converted list in list mode and the first element
+in scalar mode.
+
+=cut
+
+## convert a list of values from its LDAP filter encoding ##
+# Synopsis:  @values = unescape_dn_value(@escaped)
+sub unescape_dn_value(@)
+{
+my @values = @_;
+
+  map { $_ =~ s/\\([\\",=+<>#;]|[0-9a-fA-F]{2})
+               /(length($1)==1) ? $1 : pack("H2",$1)
+               /ogex; } @values;
+
+  return(wantarray ? @values : $values[0]);
+}
+
+
 =back
 
+
 =head1 AUTHOR
 
 Graham Barr E<lt>gbarr@pobox.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1999-2002 Graham Barr. All rights reserved. This program is
+Copyright (c) 1999-2004 Graham Barr. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
@@ -488,10 +614,6 @@ ldap_explode_dn and canonical_dn also
 
 (c) 2002 Norbert Klasen, norbert.klasen@daasi.de, All Rights Reserved.
 
-=for html <hr>
-
-I<$Id: Util.pm,v 1.18 2003/05/20 14:58:49 chrisridd Exp $>
-
 =cut
 
 1;
