@@ -1,11 +1,11 @@
-# Copyright (c) 2003 Derrik Pates <dpates@dsdk12.net> and Graham Barr
+# Copyright (c) 2003-2004 Derrik Pates <dpates@dsdk12.net> and Graham Barr
 # <gbarr@pobox.com>. All rights reserved.  This program is free
 # software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 
 package Net::LDAPI;
 @Net::LDAPI::ISA = ( 'Net::LDAP' );
-$Net::LDAPI::VERSION = "0.02";
+$Net::LDAPI::VERSION = "0.03";
 
 use strict;
 use Net::LDAP;
@@ -26,7 +26,7 @@ Net::LDAPI - use LDAP over a UNIX domain socket
 
  use Net::LDAPI;
 
- $ldapi = Net::LDAPI->new('/var/lib/ldapi');
+ $ldapi = Net::LDAPI->new('/var/run/ldapi');
 
  # alternate way
  use Net::LDAP;
@@ -69,7 +69,7 @@ Derrik Pates E<lt>dpates@dsdk12.netE<gt>
 
 =head1 COPYRIGHT
 
-Original code Copyright (c) 2003, Derrik Pates and Graham Barr. All
+Copyright (c) 2003-2004, Derrik Pates and Graham Barr. All
 rights reserved. This library is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
