@@ -9,9 +9,12 @@ BEGIN {
   # If your host cannot be contacted as localhost, change this
   $HOST     ||= '127.0.0.1';
 
-  # Where to but temporary files while testing
+  # Where to put temporary files while testing
   # the Makefile is setup to delete temp/ when make clean is run
   $TEMPDIR  = "./temp";
+  $SCHEMA_DIR ||= "./data";
+  $SLAPD_DB ||= 'ldbm';
+  $SCHEMA_CHECK = 1 unless defined $SCHEMA_CHECK;
 
   $TESTDB   = "$TEMPDIR/test-db";
   $CONF     = "$TEMPDIR/conf";
@@ -21,6 +24,7 @@ BEGIN {
   $JAJDN    = "cn=James A Jones 1, ou=Alumni Association, ou=People, o=University of Michigan, c=US";
   $BABSDN   = "cn=Barbara Jensen, ou=Information Technology Division, ou=People, o=University of Michigan, c=US";
   $PORT     = 9009;
+  @URL      = ();
 
   my @server_opts;
   ($SERVER_TYPE,@server_opts) = split(/\+/, $SERVER_TYPE || 'none');
@@ -31,11 +35,16 @@ BEGIN {
     $LDAP_VERSION = 2;
   }
   elsif ($SERVER_TYPE eq 'openldap2') {
-    $SSL_PORT = 9010 if grep { $_ eq 'ssl' } @server_opts;
+    $SSL_PORT = 9010 if grep { $_ eq 'ssl' } @server_opts
+      and eval { require IO::Socket::SSL; 1};
+    ($IPC_SOCK = "$TEMPDIR/ldapi_sock") =~ s,/,%2f,g if grep { $_ eq 'ipc' } @server_opts;
+    $SASL = 1 if grep { $_ eq 'sasl' } @server_opts
+      and eval { require Authen::SASL; 1 };
     $CONF_IN	  = "./data/slapd2-conf.in";
-    my $url = "ldap://${HOST}:$PORT/";
-    $url .= " ldaps://${HOST}:$SSL_PORT/" if $SSL_PORT;
-    @LDAPD	  = ($SERVER_EXE, '-f',$CONF,'-h',$url,qw(-d 1));
+    push @URL, "ldap://${HOST}:$PORT/";
+    push @URL, "ldaps://${HOST}:$SSL_PORT/" if $SSL_PORT;
+    push @URL, "ldapi://$IPC_SOCK/" if $IPC_SOCK;
+    @LDAPD	  = ($SERVER_EXE, '-f',$CONF,'-h', "@URL",qw(-d 1));
     $LDAP_VERSION = 3;
   }
 
@@ -46,6 +55,7 @@ BEGIN {
 
 use Net::LDAP;
 use Net::LDAP::LDIF;
+use Net::LDAP::Util qw(canonical_dn);
 use File::Path qw(rmtree);
 use File::Basename qw(basename);
 
@@ -56,9 +66,10 @@ sub start_server {
 
   unless ($LDAP_VERSION >= $arg{version}
 	and $LDAPD[0] and -x $LDAPD[0]
-	and (!$arg{ssl} or $SSL_PORT))
+	and (!$arg{ssl} or $SSL_PORT)
+	and (!$arg{ipc} or $IPC_SOCK))
   {
-    print "1..0\n";
+    print "1..0 # Skip No server\n";
     exit;
   }
 
@@ -67,8 +78,10 @@ sub start_server {
     open(CONFI,"<$CONF_IN") or die "$!";
     open(CONFO,">$CONF") or die "$!";
     while(<CONFI>) {
-      s/\$(\w+)/${$1}/g;
+      s/\$([A-Z]\w*)/${$1}/g;
       s/^TLS/#TLS/ unless $SSL_PORT;
+      s/^(sasl.*)/#$1/ unless $SASL;
+      s/^schemacheck.*// unless $SCHEMA_CHECK;
       print CONFO;
     }
     close(CONFI);
@@ -79,6 +92,8 @@ sub start_server {
   mkdir($TESTDB,0777);
   die "$TESTDB is not a directory" unless -d $TESTDB;
 
+  warn "@LDAPD" if $ENV{TEST_VERBOSE};
+
   my $log = $TEMPDIR . "/" . basename($0,'.t');
 
   unless ($pid = fork) {
@@ -118,8 +133,22 @@ sub client {
       sleep 1;
     }
   }
+  elsif ($arg{ipc}) {
+    require Net::LDAPI;
+    until($ldap = Net::LDAPI->new($IPC_SOCK)) {
+      die "ldapi://$IPC_SOCK/ $@" if ++$count > 10;
+      sleep 1;
+    }
+  }
+  elsif ($arg{url}) {
+    print "Trying $arg{url}\n";
+    until($ldap = Net::LDAP->new($arg{url})) {
+      die "$arg{url} $@" if ++$count > 10;
+      sleep 1;
+    }
+  }
   else {
-    until($ldap = Net::LDAP->new($HOST, port => $PORT)) {
+    until($ldap = Net::LDAP->new($HOST, port => $PORT, version => $LDAP_VERSION)) {
       die "ldap://$HOST:$PORT/ $@" if ++$count > 10;
       sleep 1;
     }
@@ -141,9 +170,14 @@ sub compare_ldif {
     return;
   }
 
+  my @canon_opt = (casefold => 'lower', separator => ', ');
   foreach $entry (@_) {
+    $entry->dn(canonical_dn($entry->dn, @canon_opt));
     foreach $attr ($entry->attributes) {
       $entry->delete($attr) if $attr =~ /^(modifiersname|modifytimestamp|creatorsname|createtimestamp)$/i;
+      if ($attr =~ /^(seealso|member|owner)$/i) {
+	$entry->replace($attr => [ map { canonical_dn($_, @canon_opt) } $entry->get_value($attr) ]);
+      }
     }
     $ldif->write($entry);
   }
@@ -216,5 +250,3 @@ sub skip {
 }
 
 1;
-
-1;
